define(["require", "exports", "../../Styling"], function (require, exports, Styling_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.animationDuration = Styling_1.AnimationVariables.durationValue2;
    var globalClassNames = {
        root: 'ms-Modal',
        main: 'ms-Dialog-main',
        scrollableContent: 'ms-Modal-scrollableContent',
        isOpen: 'is-open'
    };
    exports.getStyles = function (props) {
        var className = props.className, containerClassName = props.containerClassName, scrollableContentClassName = props.scrollableContentClassName, isOpen = props.isOpen, isVisible = props.isVisible, hasBeenOpened = props.hasBeenOpened, modalRectangleTop = props.modalRectangleTop, theme = props.theme, topOffsetFixed = props.topOffsetFixed;
        var palette = theme.palette;
        var classNames = Styling_1.getGlobalClassNames(globalClassNames, theme);
        return {
            root: [
                classNames.root,
                theme.fonts.medium,
                {
                    backgroundColor: 'transparent',
                    position: 'fixed',
                    height: '100%',
                    width: '100%',
                    display: 'flex',
                    alignItems: 'center',
                    justifyContent: 'center',
                    opacity: 0,
                    pointerEvents: 'none',
                    transition: "opacity " + exports.animationDuration
                },
                topOffsetFixed &&
                    hasBeenOpened && {
                    alignItems: 'flex-start'
                },
                isOpen && classNames.isOpen,
                isVisible && {
                    opacity: 1,
                    pointerEvents: 'auto'
                },
                className
            ],
            main: [
                classNames.main,
                {
                    boxShadow: '0 0 5px 0 rgba(0, 0, 0, 0.4)',
                    backgroundColor: palette.white,
                    boxSizing: 'border-box',
                    position: 'relative',
                    textAlign: 'left',
                    outline: '3px solid transparent',
                    maxHeight: '100%',
                    overflowY: 'auto'
                },
                topOffsetFixed &&
                    hasBeenOpened && {
                    top: modalRectangleTop
                },
                containerClassName
            ],
            scrollableContent: [
                classNames.scrollableContent,
                {
                    overflowY: 'auto',
                    flexGrow: 1
                },
                scrollableContentClassName
            ]
        };
    };
});
//# sourceMappingURL=Modal.styles.js.map